@@ -81,6 +81,10 @@ public class CountryDistancer {
 		while (it.hasNext()) {
 			Feature f = (Feature) it.next();
 
+            // drop features with NA country codes
+            int ctrid = ((Number) f.getAttribute(ctrcode)).intValue();
+            if (ctrid<=0) continue;
+
 			int startyear = ((Number) f.getAttribute(syear)).intValue();
 			int startmonth = ((Number) f.getAttribute(smonth)).intValue();
 			int startday = ((Number) f.getAttribute(sday)).intValue();
